import type { BuildParams } from 'glightbox-plugin';
import { GLightboxPlugin } from 'glightbox-plugin';

declare interface AppearaceOptions {
    /**
     * Define a custom theme it will
     * add a class to the lightbox so you can
     * change the appearance with CSS
     *
     * @default 'clean'
     */
    theme?: string;
    /**
     * Set your own svg icons.
     */
    slideEffect?: string | false;
    /**
     * Set your open effect
     */
    openEffect?: string | false;
    /**
     * More text for descriptions on mobile devices.
     *
     * @default 'See more'
     */
    moreText?: string;
    /**
     * Number of characters to display on the description before adding
     * the moreText link (only for mobiles),
     * if 0 it will display the entire description.
     *
     * @default 60
     */
    moreLength?: number;
    /**
     * Name of the effect on lightbox close. (zoom, fade, none)
     *
     * @default 'zoom'
     */
    closeEffect?: string;
    /**
     * You can completely change the html of GLightbox.
     */
    lightboxHTML?: string;
    /**
     * You can completely change the html of the individual slide.
     */
    slideHTML?: string;
    /**
     * Set your own svg icons.
     */
    svg?: Record<'close' | 'next' | 'prev' | 'loader', string>;
}

export declare class GLightbox {
    options: GLightboxOptions;
    apiEvents: Set<any>;
    events: Map<string, Function>;
    state: Map<string, number | boolean | HTMLElement>;
    plugins: Map<string, any>;
    items: Set<SlideConfig>;
    modal: HTMLElement | null;
    prevButton: HTMLButtonElement | null;
    nextButton: HTMLButtonElement | null;
    overlay: HTMLButtonElement | null;
    slidesContainer: HTMLElement | null;
    constructor(options?: Partial<GLightboxOptions>);
    private init;
    open(startAt: number | HTMLElement | undefined): void;
    prevSlide(): void;
    nextSlide(): void;
    goToSlide(index?: number): void;
    private showSlide;
    private setActiveSlideState;
    private preloadSlide;
    private build;
    close(): Promise<void>;
    destroy(): void;
    reload(): void;
    setItems(items: SlideConfig[]): void;
    private setItemsFromNode;
    private setItemsFromSelector;
    getSettings(): GLightboxOptions;
    private getElementIndex;
    getActiveSlideIndex(): number;
    getTotalSlides(): number;
    getItems(): Set<SlideConfig>;
    updateNavigationButtons(): void;
    private setSlideError;
    private afterSlideLoaded;
    protected on(evt: string, callback: Function, once?: boolean): void;
    protected once(evt: string, callback: Function): void;
    protected trigger(eventName: string, data?: any): void;
    private parseConfigFromNode;
    private getRegisteredSlideType;
    processVariables(node: HTMLElement): void;
    protected registerPlugin(plugin: any): void;
    protected initPlugins(): void;
    protected runPluginsMethod(method: string): void;
    pluginsRunEach(callback: Function): void;
    protected injectCSS(css: string): void;
    private clearAllEvents;
}

declare interface GLightboxOptions {
    plugins: any[];
    /**
     * Name of the selector for example '.glightbox' or 'data-glightbox'
     * or '*[data-glightbox]'
     *
     * @default '*[data-glightbox]'
     */
    selector?: string;
    /**
     * Automatically make all items with the same selector a gallery
     * if false each item will be displayed individually
     *
     * @default true
     */
    autoGallery?: boolean;
    /**
     * Name of the effect on lightbox open. (zoom, fade, none)
     *
     * @default 'zoom'
     */
    appearance?: AppearaceOptions;
    /**
     * Name of the effect on slide change. (slide, fade, zoom, none)
     *
     * @default 'slide'
     */
    slideEffect?: string;
    /**
     * Close the lightbox when clicking outside the active slide.
     *
     * @default true
     */
    closeOnOutsideClick?: boolean;
    /**
     * Start lightbox at defined index.
     *
     * @default 0
     */
    startAt?: number;
    /**
     * Enable or disable preloading.
     * If enabled, adjacent slides to the currently displayed will be preloaded
     *
     * @default true
     */
    preload?: boolean;
    /**
     * Loop slides on end.
     *
     * @default false
     */
    loop?: boolean;
    /**
     * List of custom data attributes
     * you can define custom data attributes
     * so they get parsed and you can use them
     * in the slide
     *
     * @default []
     */
    customDataAttributes?: string[];
    /**
     * Custom prefix for data attributes
     * so instead of data-url you can define
     * data-prefix-url
     *
     * @default ''
     */
    dataAttributesPrefix?: string;
}

declare interface ImageOptions {
    maxWidth?: string;
    matchFn?: Function;
}

export declare class ImageSlide extends GLightboxPlugin {
    name: string;
    type: string;
    options: ImageOptions;
    defaults: ImageOptions;
    constructor(options?: Partial<ImageOptions>);
    match(url: string): boolean;
    build({ index, slide, config }: BuildParams): Promise<boolean>;
    cssStyle(): string;
}

declare interface SlideConfig {
    node?: Element | null;
    url: string;
    thumbnail?: string;
    title?: string;
    description?: string;
    html?: boolean;
    zoomable?: boolean;
    draggable?: boolean;
    [key: string]: any;
}

export { }
